==> storify-0.0.5.tgz: package/lib/story.js <==
var path = require('path');

var Story = function(s, story) {
  var self = this;
  self.info= {};
  Object.keys(story).forEach(function(p) {
    self[p] = self.info[p] = story[p];
  });
  
  this._api = s;
};

Story.prototype = {
  
  getElements: function(params, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    return this.get('/elements', params, function(e, res) {
      fn(e, res);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    params.username = this.author.username;
    params._token = this.author._token;
    route = path.join('/stories', this.author.username, this.slug, route);
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    params.username = this.author.username;
    params._token = this.author._token;
    route = path.join('/stories', this.author.username, this.slug, route);
    
    return this._api.request(route, params, options, fn);
  }
  
};

module.exports = Story;

==> storify-0.0.15.tgz: package/lib/story.js <==
var path = require('path');

var Story = function(s, story) {
  var self = this;
  self.info= {};
  Object.keys(story).forEach(function(p) {
    self[p] = self.info[p] = story[p];
  });
  
  this._api = s;
};

Story.prototype = {
  
  getElements: function(params, options, fn) {
    if (typeof options == 'function') {
      fn = options;
      options = {};
    }
    
    if (typeof params == 'function') {
      fn = params;
      params = options = {};
    }
    
    return this.get('/elements', params, options, function(e, res) {
      fn(e, res);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    params.username = this.author.username;
    params._token = this.author._token;
    route = path.join('/stories', this.author.username, this.slug, route);
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    params.username = this.author.username;
    params._token = this.author._token;
    route = path.join('/stories', this.author.username, this.slug, route);
    
    return this._api.request(route, params, options, fn);
  }
  
};

module.exports = Story;
